@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.3
--- Copyright (C) 2010  quvi project
+-- libquvi-scripts v0.4.8
+-- Copyright (C) 2012  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -21,7 +21,7 @@
 --
 
 -- Identify the script.
-function ident (self)
+function ident(self)
     package.path = self.script_dir .. '/?.lua'
     local C      = require 'quvi/const'
     local r      = {}
@@ -29,7 +29,7 @@ function ident (self)
     r.formats    = "default"
     r.categories = C.proto_http
     local U      = require 'quvi/util'
-    r.handles    = U.handles(self.page_url, {r.domain}, {"/video/"})
+    r.handles    = U.handles(self.page_url, {r.domain}, {"/video/.-,%d+/"})
     return r
 end
 
@@ -40,24 +40,23 @@ function query_formats(self)
 end
 
 -- Parse media URL.
-function parse (self)
+function parse(self)
     self.host_id = "theonion"
-    local page   = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("<title>(.-) |")
-    self.title  = s or error ("no match: media title")
+    self.id = self.page_url:match(',(%d+)/') or error('no match: media ID')
 
-    local _,_,s = page:find('afns_video_id = "(.-)";')
-    self.id     = s or error ("no match: media id")
+    local u = string.format('http://theonion.com/videos/embed/%s.json',
+                              self.id)
 
-    local _,_,s = page:find('http://www.theonion.com/video/(.-),')
-    s           = s or error ("no match: flv url")
+    local c = quvi.fetch(u, {fetch_type='config'})
 
-    s = string.format(
-        "http://videos.theonion.com/onion_video/auto/%s/%s-iphone.m4v",
-        self.id, s
-    )
-    self.url   = {s}
+    self.title = c:match('"title":%s+"(.-)"')
+                  or error('no match: media title')
+
+    self.thumbnail_url = c:match('"thumbnail":%s+"(.-)"') or ''
+
+    self.url = {c:match('"video_url":%s+"(.-)"')
+                  or error('no match: media stream URL')}
 
     return self
 end
